/**************************************************************************//**
*   @file   main.c
*   @brief  AD7156 Main Driver file.
*   @author ATofan (alexandru.tofan@analog.com)
*
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: $WCREV$
******************************************************************************/

#include <stdio.h>
#include "xparameters.h"
#include "xil_io.h"
#include "xil_cache.h"
#include "i2c.h"
#include "AD7156.h"
#include "mb_interrupts.h"

volatile char 			rxData 		 = 0;
//volatile float 		inputRange 	 = 2;
volatile float			rangeCh1	 = 2;
volatile float			rangeCh2	 = 2;
volatile char 			selChan 	 = 0x03;
volatile char 			thrFixed 	 = 0x01;
volatile char 			thrType 	 = 0x00;
volatile int 			threshChan1  = 0x8000;
volatile int 			threshChan2  = 0x8000;
volatile unsigned char 	sensChan1 	 = 0x08;
volatile unsigned char 	sensChan2 	 = 0x08;
volatile unsigned char 	timeOutChan1 = 0x86;
volatile unsigned char 	timeOutChan2 = 0x86;

/******************************************************************************
* @brief Main function.
*
* @param None.
*
* @return Always returns 0.
******************************************************************************/
int main(void)
{
	Xil_ICacheEnable();
	Xil_ICacheDisable();

	// Initialize I2C
	I2C_Init(I2C_BASEADDR, AD7156_I2C_ADDR);

	// Initialize AD7156
	AD7156_Init();

	// Enable Microblaze Interrupts
	enableInterrupts();

	// Display Main Menu
	AD7156_DisplayMainMenu();

	while(1)
	{
		switch(rxData)
		{
			case 's':
				AD7156_DisplayCurrentSettings();
				break;
			case 'c':
				AD7156_Print(selChan);
				break;
			case 'a':
				AD7156_PrintAverage(selChan);
				break;
			case 't':
				AD7156_SetThreshold();
				break;
			case 'd':
				AD7156_SelChannels();
				break;
			case 'm':
				AD7156_SelThreshold();
				break;
			case 'r':
				AD7156_SetRange();
				break;
			case 'q':
				AD7156_DisplayMenu();
				break;
			case 0:
				break;
			default:
				xil_printf("\n\rWrong option! Please select one of the options below:");
				AD7156_DisplayMenu();
				break;
		}
	}

	Xil_ICacheDisable();
	Xil_DCacheDisable();
	return(0);
}
